summaryrefslogtreecommitdiff
path: root/qadevOOo/tests/java/ifc/container/_XContainerQuery.java
diff options
context:
space:
mode:
Diffstat (limited to 'qadevOOo/tests/java/ifc/container/_XContainerQuery.java')
-rw-r--r--qadevOOo/tests/java/ifc/container/_XContainerQuery.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/qadevOOo/tests/java/ifc/container/_XContainerQuery.java b/qadevOOo/tests/java/ifc/container/_XContainerQuery.java
index 2d7659bfb244..06f6301ded7d 100644
--- a/qadevOOo/tests/java/ifc/container/_XContainerQuery.java
+++ b/qadevOOo/tests/java/ifc/container/_XContainerQuery.java
@@ -43,7 +43,7 @@ import com.sun.star.container.XEnumeration;
* Normaly <code>createSubSetEnumerationByProperties()</code> covers all
* possible queries. But for special cases, i.e. sorted output, the function
* <code>createSubSetEnumerationByQuery()</code> was made. The special cases was not
* implemented by default in the implemetation object. So this function could be
* marked as <code>optional</code></li>
* <ul> <p>
* <p>
@@ -90,7 +90,7 @@ public class _XContainerQuery extends MultiMethodTest {
boolean bResult = true;
if ( m_queryStrings == null ) {
- log.println("This object does not have an implemetation for this function");
+ log.println("This object does not have an implementation for this function");
// This is not a bug, because it's a feature for future purposes
} else {
for (int i = 0; i < m_queryStrings.length; i++){
@@ -43,7 +43,7 @@ import com.sun.star.container.XEnumeration;
* possible queries. But for special cases, i.e. sorted output, the function
* <code>createSubSetEnumerationByQuery()</code> was made. The special cases was not
-* implemented by default in the implemetation object. So this function could be
+* implemented by default in the implementation object. So this function could be
* marked as <code>optional</code></li>
* <ul> <p>